%% Author 
% Oskar Lund, 29.10.17
% Thesis - Butterfly Robot

%% Description
% This script simulates the overall behaviour of the 
% butterfly robot, but with the butterfly shape
% switched out with a circular shape

%% Clear all variables and figures
clear all;
close all;

%% Define the object BR of class ButterflyRobot
CR = CircleRobot;

%% Choose which program to run: ABG = 0, BR = 1
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
program = 1;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

if (program == 0)
        %% Simulate alpha, beta, gamma
        
    t0_   = 0;  % Intial time
    tEnd_ = 10;  % Final time
    x0_   = [0; 1]; % Initial conditions ([varphi0;Dvarphi0])
    [t_,x_] = CR.simABG(t0_,tEnd_,x0_);
    findIndex = length(find(x_(:,1) <= 2*pi));
    x_ = x_(1:findIndex,:);
    
    figure
        grid on
        zoom on
        hold on
        plot(x_(:,1),x_(:,2))
        ax = gca;
        ax.XTick = [0 pi/2 pi 3*pi/2 2*pi];
        ax.XTickLabels = ({'0','$$\frac{1}{2}\pi$$','$$\pi$$','$$\frac{3}{2}\pi$$','$$2\pi$$'});
        ax.TickLabelInterpreter = ('latex');
        xlabel('$\varphi$','Interpreter','latex')
        ylabel('$\dot\varphi$','Interpreter','latex')
        title('Phase Trajectory')
    %cleanfigure;
    %matlab2tikz();

elseif (program == 1)
        %% Simulate the full circle system
        
    t0   = 0;  % Intial time
    tEnd = 5;  % Final time
    x0   = [0; pi/2; 0; 0]; % Initial conditions ([theta0;varphi0;Dtheta0;Dvarphi0])
    [t,x] = CR.simCR(t0,tEnd,x0);
    findIndex = length(find(x(:,2) <= 2*pi));
    x = x(1:findIndex,:);
    t = t(1:findIndex,:);
    
    figure
        grid on
        zoom on
        hold on
        plot(t,x(:,1),'r','LineWidth',1.5)
        plot(t,x(:,2),'b','LineWidth',1.5)
        ax = gca;
        ax.YTick = [-2*pi -3*pi/2 -pi -pi/2 0 pi/2 pi 3*pi/2 2*pi];
        ax.YTickLabels = ({'-$$2\pi$$','-$$\frac{3}{2}\pi$$','-$$\pi$$','-$$\frac{1}{2}\pi$$',...
            '0','$$\frac{1}{2}\pi$$','$$\pi$$','$$\frac{3}{2}\pi$$','$$2\pi$$'});
        ax.TickLabelInterpreter = ('latex');
        xlabel('Time [s]','Interpreter','latex')
        ylabel('Angle [rad]','Interpreter','latex')
        title('Behaviour of the Degrees of Freedom')
        h = legend('$\theta(t)$','$\varphi(t)$', 'Location','NorthEast');
        set(h,'Interpreter','latex')
%     cleanfigure;
%     matlab2tikz();

    figure
        grid on
        zoom on
        hold on
        plot(x(:,2),x(:,1))
        ax = gca;
        ax.XTick = [0 pi/2 pi 3*pi/2 2*pi];
        ax.XTickLabels = ({'0','$$\frac{1}{2}\pi$$','$$\pi$$','$$\frac{3}{2}\pi$$','$$2\pi$$'});
        ax.YTick = [0 pi/2 pi 3*pi/2 2*pi];
        ax.YTickLabels = ({'0','$$\frac{1}{2}\pi$$','$$\pi$$','$$\frac{3}{2}\pi$$','$$2\pi$$'});
        ax.TickLabelInterpreter = ('latex');
        xlabel('$\varphi$','Interpreter','latex')
        ylabel('$\theta$','Interpreter','latex')
        title('Relationship Between General Coordinates')
%     cleanfigure;
%     matlab2tikz();

    figure
        grid on
        zoom on
        hold on
        plot(x(:,2),x(:,4))
        ax = gca;
        ax.XTick = [0 pi/2 pi 3*pi/2 2*pi];
        ax.XTickLabels = ({'0','$$\frac{1}{2}\pi$$','$$\pi$$','$$\frac{3}{2}\pi$$','$$2\pi$$'});
        ax.TickLabelInterpreter = ('latex');
        xlabel('$\varphi$','Interpreter','latex')
        ylabel('$\dot\varphi$','Interpreter','latex')
        title('Phase Trajectory')
%     cleanfigure;
%     matlab2tikz();
end
