%% Author 
% Oskar Lund, 11.10.17
% Thesis - Butterfly Robot

%% Description
% This script simulates the overall behaviour of the 
% butterfly robot, in addition to all the subparts

%% Clear all variables and figures
clear all;
close all;

%% Define the object BR of class ButterflyRobot
BR = ButterflyRobot;

%% Choose which program to run: ABG = 0, BR = 1
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
program = 1;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

if (program == 0)
        %% Simulate alpha, beta, gamma
        
    t0_   = 0;  % Intial time
    tEnd_ = 10;  % Final time
    x0_   = [0; 4.3]; % Initial conditions ([varphi0;Dvarphi0])
    [t_,x_] = BR.simABG(t0_,tEnd_,x0_);
    findIndex = length(find(x_(:,1) <= 2*pi));
    x_ = x_(1:findIndex,:);
    
    figure
        grid on
        zoom on
        hold on
        plot(x_(:,1),x_(:,2));
        ax = gca;
        ax.XTick = [0 pi/2 pi 3*pi/2 2*pi];
        ax.XTickLabels = ({'0','$$\frac{1}{2}\pi$$','$$\pi$$','$$\frac{3}{2}\pi$$','$$2\pi$$'});
        ax.TickLabelInterpreter = ('latex');
        xlabel('$\varphi$','Interpreter','latex')
        ylabel('$\dot\varphi$','Interpreter','latex')
        title('Phase Trajectory')
%     cleanfigure;
%     matlab2tikz();

elseif (program == 1)
        %% Simulate the full butterfly system
        
    t0   = 0;  % Intial time
    tEnd = 5;  % Final time
    x0   = [0; 0; 0.086; 4.3]; % Initial conditions ([theta0;varphi0;Dtheta0;Dvarphi0])
    [t,x,Fn,Fs,u] = BR.simBR(t0,tEnd,x0);
    findIndex = length(find(x(:,2) <= 2*pi));
    x = x(1:findIndex,:);
    t = t(1:findIndex,:);
    Fn = Fn(1:findIndex,:);
    Fs = Fs(1:findIndex,:);
    u = u(1:findIndex,:);
%     cleanfigure;
%     matlab2tikz();

    figure
        grid on
        zoom on
        hold on
        plot(t,u,'LineWidth',1.5)
        xlabel('Time [s]','Interpreter','latex')
        ylabel('Input force [Nm]','Interpreter','latex')
        title('Actuation')
%     cleanfigure;
%     matlab2tikz();    
%    
    figure
        grid on
        zoom on
        hold on
        plot(t,x(:,1),'r','LineWidth',1.5)
        plot(t,x(:,2),'b','LineWidth',1.5)
        ax = gca;
        ax.YTick = [-2*pi -3*pi/2 -pi -pi/2 0 pi/2 pi 3*pi/2 2*pi];
        ax.YTickLabels = ({'-$$2\pi$$','-$$\frac{3}{2}\pi$$','-$$\pi$$','-$$\frac{1}{2}\pi$$',...
            '0','$$\frac{1}{2}\pi$$','$$\pi$$','$$\frac{3}{2}\pi$$','$$2\pi$$'});
        ax.TickLabelInterpreter = ('latex');
        xlabel('Time [s]','Interpreter','latex')
        ylabel('Angle [rad]','Interpreter','latex')
        title('Angular Position of the Genereal Coordinates')
        h = legend('$\theta(t)$','$\varphi(t)$', 'Location','NorthEast');
        set(h,'Interpreter','latex')
%     cleanfigure;
%     matlab2tikz();

    figure
        grid on
        zoom on
        hold on
        plot(t,x(:,3),'r','LineWidth',1.5)
        plot(t,x(:,4),'b','LineWidth',1.5)
        ax = gca;
        ax.YTick = [-2*pi -3*pi/2 -pi -pi/2 0 pi/2 pi 3*pi/2 2*pi];
        ax.YTickLabels = ({'-$$2\pi$$','-$$\frac{3}{2}\pi$$','-$$\pi$$','-$$\frac{1}{2}\pi$$',...
            '0','$$\frac{1}{2}\pi$$','$$\pi$$','$$\frac{3}{2}\pi$$','$$2\pi$$'});
        ax.TickLabelInterpreter = ('latex');
        xlabel('Time [s]','Interpreter','latex')
        ylabel('Angle [rad]','Interpreter','latex')
        title('Angular Velocity of the Genereal Coordinates')
        h = legend('$\dot{\theta}(t)$','$\dot{\varphi}(t)$', 'Location','NorthEast');
        set(h,'Interpreter','latex')
%     cleanfigure;
%     matlab2tikz();

    figure
        grid on
        zoom on
        hold on
        plot(x(:,2),x(:,1),'LineWidth',1.5)
        axis([0 (2*pi)+(pi/5) 0 (2*pi)+(pi/5)])
        ax = gca;
        ax.XTick = [-2*pi -3*pi/2 -pi -pi/2 0 pi/2 pi 3*pi/2 2*pi];
        ax.XTickLabels = ({'-$$2\pi$$','-$$\frac{3}{2}\pi$$','-$$\pi$$','-$$\frac{1}{2}\pi$$',...
            '0','$$\frac{1}{2}\pi$$','$$\pi$$','$$\frac{3}{2}\pi$$','$$2\pi$$'});
        ax.YTick = [0 pi/2 pi 3*pi/2 2*pi];
        ax.YTickLabels = ({'0','$$\frac{1}{2}\pi$$','$$\pi$$','$$\frac{3}{2}\pi$$','$$2\pi$$'});
        ax.TickLabelInterpreter = ('latex');
        xlabel('$\varphi$','Interpreter','latex')
        ylabel('$\theta$','Interpreter','latex')
        title('Relationship Between General Coordinates')
%     cleanfigure;
%     matlab2tikz();

    figure
        grid on
        zoom on
        hold on
        plot(x(:,2),x(:,4))
        ax = gca;
        ax.XTick = [-2*pi -3*pi/2 -pi -pi/2 0 pi/2 pi 3*pi/2 2*pi];
        ax.XTickLabels = ({'-$$2\pi$$','-$$\frac{3}{2}\pi$$','-$$\pi$$','-$$\frac{1}{2}\pi$$',...
            '0','$$\frac{1}{2}\pi$$','$$\pi$$','$$\frac{3}{2}\pi$$','$$2\pi$$'});
        ax.TickLabelInterpreter = ('latex');
        xlabel('$\varphi$','Interpreter','latex')
        ylabel('$\dot\varphi$','Interpreter','latex')
        title('Phase Trajectory')
%     cleanfigure;
%     matlab2tikz();

    figure
        grid on
        zoom on
        hold on        
        plot(t,Fn,'m','LineWidth',1.5)
        plot(t,Fs,'g','LineWidth',1.5)
        xlabel('Time [s]','Interpreter','latex')
        ylabel('Force [N]','Interpreter','latex')
        title('Friction and slip forces VS time')
        h = legend('$F_n$','$F_s$', 'Location','Best');
        set(h,'Interpreter','latex')
        set(h,'FontSize',14)
%     cleanfigure;
%     matlab2tikz();

    figure
        grid on
        zoom on
        hold on        
        plot(x(:,2),Fn,'m','LineWidth',1.5)
        plot(x(:,2),Fs,'g','LineWidth',1.5)
        ax = gca;
        ax.XTick = [0 pi/2 pi 3*pi/2 2*pi];
        ax.XTickLabels = ({'0','$$\frac{1}{2}\pi$$','$$\pi$$','$$\frac{3}{2}\pi$$','$$2\pi$$'});
        ax.TickLabelInterpreter = ('latex');
        xlabel('$\varphi$','Interpreter','latex')
        ylabel('Force [N]','Interpreter','latex')
        title('Friction and slip forces VS varphi')
        h = legend('$F_n$','$F_s$', 'Location','Best');
        set(h,'Interpreter','latex')
        set(h,'FontSize',14)
%     cleanfigure;
%     matlab2tikz();

end

